/*
 * This file is part of cobertura4sbt.
 *
 * Copyright (c) 2010 Joachim Hofer
 * All rights reserved.
 *
 * This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 */
package de.johoop.cobertura4sbt

import sbt._

trait Cobertura extends DefaultProject
    with CommandLineExecutor
    with CoberturaDependencies
    with CoberturaProperties {

  lazy val coberturaInstrument = task {
    import java.io.File
    import sbt.FileUtilities._

    system[String]("net.sourceforge.cobertura.datafile").update(coberturaDataFile.toString)

    val commandLine = List("java", "-cp", coberturaClasspath, "net.sourceforge.cobertura.instrument.Main")

    val additionalArgs =
        "--datafile" :: coberturaDataFile.absolutePath ::
        coberturaLinesToExclude.flatMap(str => List("--ignore", str)) ++
        coberturaClassesToExclude.flatMap(str => List("--excludeClasses", "\\.\\." + str)) ++
        coberturaClassesToInclude.flatMap(str => List("--includeClasses", "\\.\\." + str)) ++
        coberturaPathsToInstrument.flatMap(path => List("--basedir", path.relativePath, "."))

    executeCoberturaCommandLine(commandLine ++ additionalArgs)

  } dependsOn(testCompile) describedAs("Instruments all non-test classes for coverage measurement via Cobertura.")

  lazy val coberturaReportXml = task {
    coberturaReportForFormat("xml")
  } describedAs("Outputs the Cobertura coverage report as XML file.")

  lazy val coberturaReportHtml = task {
    coberturaReportForFormat("html")
  } describedAs("Outputs the Cobertura coverage report as HTML report.")

  private def coberturaReportForFormat(format: String) = {
    import sbt.FileUtilities._

    createDirectory(coberturaReportPath, log)

    val commandLine = List[String](
        "java", "-cp", coberturaClasspath, "net.sourceforge.cobertura.reporting.Main",
        "--encoding", coberturaSourceEncoding, "--format", format, 
        "--destination", coberturaReportPath.relativePath,
        "--datafile", coberturaDataFile.relativePath) ++
        coberturaSourcePaths.map(_.relativePath)

    executeCoberturaCommandLine(commandLine)
  }

  private def coberturaClasspath =
      configurationPath(Configurations.Test).descendentsExcept("*.jar", defaultExcludes).relativeString
}

