/*
 * This file is part of cobertura4sbt.
 *
 * Copyright (c) 2010 Joachim Hofer
 * All rights reserved.
 *
 * This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 */
package de.johoop.cobertura4sbt

import sbt._

trait CoberturaProperties extends DefaultProject {

  /** The base location for all things Cobertura.
    * Defaults to <code>outputPath / "cobertura"</code>. */
  protected lazy val coberturaBasePath: Path = outputPath / "cobertura"

  /** The location of the Cobertura report files.
    * Defaults to <code>coberturaBasePath / "report"</code>. */
  protected lazy val coberturaReportPath: Path = coberturaBasePath / "report"
  
  /** The location of the data file Cobertura will initialize on instrumenting and update during runtime.
    * Defaults to <code>coberturaBasePath / "cobertura.ser"</code>. */
  protected lazy val coberturaDataFile: Path = coberturaBasePath / "cobertura.ser"

  /** A list of <code>Path</code>s specifying all the paths where there are classes to instrument.
    * Defaults to <code>List(mainCompilePath)</code>. */
  protected lazy val coberturaPathsToInstrument: List[Path] = List(mainCompilePath)
  
  /** A list of regular expressions describing classes to exclude from instrumentation. 
    * Defaults to an empty list. */
  protected lazy val coberturaClassesToExclude: List[String] = Nil

  /** A list of regular expressions describing classes to include from instrumentation. 
    * Defaults to <code>List(.*)</code>. */
  protected lazy val coberturaClassesToInclude: List[String] = List(".*")

  /** A list of regular expressions describing lines to exclude from instrumentation. 
    * Defaults to an empty list. */
  protected lazy val coberturaLinesToExclude: List[String] = List()

  /** A list of paths containing the source files (for Cobertura reporting and NCSS computation). 
    * Defaults to <code>List(mainJavaSourcePath)</code>. */
  protected lazy val coberturaSourcePaths: List[Path] = List(mainJavaSourcePath)

  /** The encoding Cobertura expects the source files to have.
    * Defaults to <code>"utf-8"</code>. */
  protected lazy val coberturaSourceEncoding: String = "utf-8"
}

