/*
 * This file is part of cobertura4sbt.
 * 
 * Copyright (c) 2010 Joachim Hofer
 * All rights reserved.
 *
 * This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 */
package de.johoop.cobertura4sbt

import sbt._
import sbt.FileUtilities._

private[cobertura4sbt] trait CommandLineExecutor extends DefaultProject with CoberturaProperties {
  private[cobertura4sbt] def executeLongCoberturaCommandLine(
      commandLine: List[String], additionalArgs: List[String]) = {
        
    val argsFilePath = coberturaBasePath / "args"
    write(argsFilePath.asFile, additionalArgs.mkString(" "), log)
    executeCoberturaCommandLine(commandLine ++ List("--commandsfile", argsFilePath.relativePath))
  }
  
  private[cobertura4sbt] def executeCoberturaCommandLine(commandLine: List[String]) = try {
    log.debug(commandLine mkString "\n")
    val exitValue = Process(commandLine) ! log
    if (exitValue == 0) None else Some("Nonzero exit value: " + exitValue)
      
  } catch {
    case e => Some("Exception while executing Cobertura: %s".format(e.getMessage))
  }
}

